==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/ClassStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassStateMachineSetImpl extends InstanceSet<ClassStateMachineSet,ClassStateMachine> implements ClassStateMachineSet {

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassStateMachine classstatemachine : this ) classstatemachine.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( ClassStateMachine classstatemachine : this ) classstatemachine.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public SM_SMSet R517_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( ClassStateMachine classstatemachine : this ) sm_smset.add( classstatemachine.R517_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public ModelClassSet R519_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassStateMachine classstatemachine : this ) modelclassset.add( classstatemachine.R519_ModelClass() );
        return modelclassset;
    }


    @Override
    public ClassStateMachine nullElement() {
        return ClassStateMachineImpl.EMPTY_CLASSSTATEMACHINE;
    }

    @Override
    public ClassStateMachineSet emptySet() {
      return new ClassStateMachineSetImpl();
    }

    @Override
    public ClassStateMachineSet value() {
        return this;
    }

    @Override
    public List<ClassStateMachine> elements() {
        return Arrays.asList(toArray(new ClassStateMachine[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/ClassStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassStateMachineSetImpl extends InstanceSet<ClassStateMachineSet,ClassStateMachine> implements ClassStateMachineSet {

    public ClassStateMachineSetImpl() {
    }

    public ClassStateMachineSetImpl(Comparator<? super ClassStateMachine> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassStateMachine classstatemachine : this ) classstatemachine.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( ClassStateMachine classstatemachine : this ) classstatemachine.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public SM_SMSet R517_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( ClassStateMachine classstatemachine : this ) sm_smset.add( classstatemachine.R517_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public ModelClassSet R519_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassStateMachine classstatemachine : this ) modelclassset.add( classstatemachine.R519_ModelClass() );
        return modelclassset;
    }


    @Override
    public ClassStateMachine nullElement() {
        return ClassStateMachineImpl.EMPTY_CLASSSTATEMACHINE;
    }

    @Override
    public ClassStateMachineSet emptySet() {
      return new ClassStateMachineSetImpl();
    }

    @Override
    public ClassStateMachineSet emptySet(Comparator<? super ClassStateMachine> comp) {
      return new ClassStateMachineSetImpl(comp);
    }

    @Override
    public ClassStateMachineSet value() {
        return this;
    }

    @Override
    public List<ClassStateMachine> elements() {
        return Arrays.asList(toArray(new ClassStateMachine[0]));
    }

}
